@@ -1,13 +1,16 @@
-﻿#Global variables
+﻿###########################################################################
+## All global variables in here are used all over the program
+###########################################################################
+
 configfolder="/home/user/.SleepAnalyser/" #users home dir with ending /
 homedir="/home/user/"
 defaultlogfolder="/home/user/MyDocs/SleepAnalyser/" #users log dir with ending /
 ConfigFile="SleepAnalyser.conf"
-#development PC:
-devconfigfolder="/home/gruinelli/Maemo/SleepAnalyser/"
-devlogfolder="/tmp/"
 
-dateformat="%Y-%m-%d %H:%M:%S"
+devconfigfolder="/home/gruinelli/Maemo/SleepAnalyser/" #development PC
+devlogfolder="/tmp/" #development PC
+
+dateformat="%Y-%m-%d %H:%M:%S" #the date/time is stored in this format in the record files
 
 #init values
 Sampling_interval=1000 #in milliseconds
@@ -15,6 +18,7 @@ Sample_index=0
 Sample_smoothing=10 #value_smoothing at 1. level
 Value_smoothing=10 #value_smoothing at 2. level
 Derivation=5 #shift in Derivation
+
 Ysize=121 #default value Y scale in px
 Yscale=1 #default value Y stretching
 arrXscale=[1, 4, 6] #scaling steps X accis
@@ -32,19 +36,14 @@ maxTrigger=100
 
 demo=0
 debug=0
-#test=0
+
 logfilename=""
 logfile=""
 logfolder=""
 lastlogfile=""
-#Note=""
-#Header=""
-#StartTime=0
-#StartTimeSec=0
-#StopTime=0
-#MidnightTransitions=0
+
 ChangesInGraph=False
-run=0
+run=False
 QuickMode=False
 version="0"
 build="0"
@@ -56,8 +55,10 @@ DelayStartTime=10
 #DropIndexes=0
 last_beep=0
 #graphBlocks=0
-OfflineMode="False"
-SilentProfile="False"
+OfflineMode=False
+PreviousMode="normal"
+SilentProfile=False
+PreviouseProfile="silent"
 #OldOfflineMode="False" #restore original state after recording
 DelayStart=0
 interval=0
