@@ -20,7 +20,7 @@ from functions_record import *
 
 
 ###########################################################################
-# Function to open or close the log file
+## Function to open or close the log file
 ###########################################################################
 def CreateRecordFile(interval):       
     #if not on the N900, use another place for the log file 
@@ -34,7 +34,7 @@ def CreateRecordFile(interval):
         except:
             print "Failed to create logfolder!"
             
-    PrintRecordData()
+    if(data.debug==1): PrintRecordData()
         
     
     #create file, write header
@@ -54,7 +54,9 @@ def CreateRecordFile(interval):
 
 
 
-
+###########################################################################
+## 
+###########################################################################
 def CreateHeader():
     if(records.SWversion<1.6): records.SWversion=1.6 #update file version sas header gets saved in new version
     h=" , , , User: " + str(records.User.encode( "utf-8" ))+ \
@@ -83,14 +85,14 @@ def CreateHeader():
     h=h+"\n"+"Time, AccX, AccY, Event:\n"
     
 #    print "Record header:\n"+h+"\n"
-    print "##############################\nHeader:\n"+h+"\n##############################"
+    if(data.debug==1): print "##############################\nHeader:\n"+h+"\n##############################"
     return h
 
 
 
 
 ###########################################################################
-#  Write data into file, so it can be used in other tools
+##  Write data into file, so it can be used in other tools
 ###########################################################################
 def WriteIntoRecordFile():
     d=str(records.arrData[0][records.Index]) + ", " +  \
@@ -103,16 +105,8 @@ def WriteIntoRecordFile():
 
 
 
-#def WriteFirstEntryIntoRecordFile():
-#    d=strftime("%H:%M:%S", records.StartTime_tuple)+", 0,  0,"
-#    
-#    data.logfile.write(d+"\n")
-#    if(data.debug==1): print d
-
-
-
 ###########################################################################
-#  Close log file
+##  Close log file
 ###########################################################################
 def StopLogfile():    
     if(records.AlarmIsSet==True): 
@@ -124,7 +118,7 @@ def StopLogfile():
 
 
 ###########################################################################
-#  Load list of log files into array
+##  Load list of log files into array
 ###########################################################################
 def LoadFileList():
     print "Load list of all csv files in folder:",  data.logfolder
@@ -144,7 +138,7 @@ def LoadFileList():
 
 
 ###########################################################################
-#  Load log file  to read and visualise it
+##  Load log file  to read and visualise it
 ###########################################################################
 def LoadRecord():    
     InitRecord() #clear all old data
@@ -204,13 +198,13 @@ def LoadRecord():
             tmp=file.readline()
     #        print tmp
             if(tmp[:-1]!="No alarm set"):
-                print "An alarm is set"
+                if(data.debug==1): print "An alarm is set"
 #                records.AlarmIsSet=True
                 tmp=string.replace(tmp[:-1], "Alarm: ",  "")
                 records.AlarmTime_tuple=time.strptime(tmp,  data.dateformat)
                 records.AlarmTime_seconds=Tuple2Seconds( records.AlarmTime_tuple)
             else:
-                print "No alarm is set"
+                if(data.debug==1): print "No alarm is set"
             
            #process header line 4
             tmp=file.readline()
@@ -296,13 +290,13 @@ def LoadRecord():
     print "Loaded successful",  records.Index, "lines"
     if(records.AlarmIsSet==True): 
         records.LastIndex=max(records.Index,  Tuple2Index(records.AlarmTimeWindowEnd_tuple)+5) #the very last index to be shown (incl. AlarmTimeWindowEnd
-        print "But will show up to index",  records.LastIndex,  "as the AlarmTimeWindow ends there"
+        if(data.debug==1): print "But will show up to index",  records.LastIndex,  "as the AlarmTimeWindow ends there"
     else: records.LastIndex=records.Index
         
     records.status="Data successful loaded"
     records.statusID="OK"
     
-    PrintRecordData(False)
+    if(data.debug==1): PrintRecordData(False)
     return 0 #all ok
     
     
@@ -312,10 +306,10 @@ def LoadRecord():
     
     
 ###########################################################################
-#  Load log file  to change Note (on line 2)
+##  
 ###########################################################################
 def UpdateFileHeader():    
-    print "Reopen log file and update note:",  records.Note
+#    print "Reopen log file and update note:",  records.Note
     file = open(data.logfolder+data.logfilename, 'w')
     print "Update header in logfile",  data.logfilename
 
@@ -326,6 +320,6 @@ def UpdateFileHeader():
         d=str(records.arrData[0][i]) + ", " + str(records.arrData[1][i]) + ", " +  str(records.arrData[2][i]) + ", " +  str(records.arrData[5][i])
         file.write(d+"\n")
     file.close()
-    print "Wrote",  i +1,  "records into file"
+    if(data.debug==1): print "Wrote",  i +1,  "records into file"
     
     
