@@ -70,7 +70,9 @@ def GetSensorData():
 
 
 
-
+###########################################################################
+## 
+###########################################################################
 def GetFirstEntry():
     records.arrData[0][0]=strftime("%H:%M:%S", time.localtime())
     records.arrData[1][0]=0
@@ -128,14 +130,14 @@ def ProcessData(ProcessAll=False):  #DERIVATION (ABLEITUNG)
 
 ###########################################################################
 ## Show (refreshs) the graph.
-## the parameter indcates on which window it will be drawn
+## the first parameter indcates on which window it will be drawn
 ###########################################################################
 def showGraph(self,  QtGui):
     if(data.ChangesInGraph==False): 
         if(data.debug==1): print "------>         Do not redraw, nothing changed!"
         return 
         
-    print data.logfilename
+#    print "Show data of file",  data.logfilename
 #    print "----------------------------"
     ScrollbarStartPercent, ScrollbarEndPercent=ScrollbarData()
     Xscale=data.arrXscale[data.Xscale]
@@ -155,7 +157,7 @@ def showGraph(self,  QtGui):
         
 #    PrintRecordData()
 
-    print "data.QuickMode:",  data.QuickMode
+#    print "data.QuickMode:",  data.QuickMode
         
     data.ChangesInGraph=False
     paint = QtGui.QPainter()
@@ -177,11 +179,11 @@ def showGraph(self,  QtGui):
     
     
     GraphStart_tuple=Index2Tuple(data.GraphStart)
-    print "data.GraphStart",  data.GraphStart,  GraphStart_tuple
+    if(data.debug==1): print "data.GraphStart",  data.GraphStart,  GraphStart_tuple
     h=int(strftime("%H", GraphStart_tuple))
     m=int(strftime("%M", GraphStart_tuple))
     s=int(strftime("%S", GraphStart_tuple))
-    print h,  m,  s
+#    print h,  m,  s
     
     secondsincefullhour=m*60+s
     GraphStart_seconds=Tuple2Seconds(GraphStart_tuple)
@@ -191,21 +193,21 @@ def showGraph(self,  QtGui):
     h0=int(strftime("%H", LastFullHour_tuple))
     m0=int(strftime("%M", LastFullHour_tuple))
     s0=int(strftime("%S", LastFullHour_tuple))
-    print h0,  m0,  s0
+#    print h0,  m0,  s0
     
     
-    print GraphStart_seconds,  LastFullHour_sec,  secondsincefullhour
-    print GraphStart_tuple,  LastFullHour_tuple
+#    print GraphStart_seconds,  LastFullHour_sec,  secondsincefullhour
+#    print GraphStart_tuple,  LastFullHour_tuple
     
     LastFullHour_index=Tuple2Index(LastFullHour_tuple)
 
     GraphStart_index=Tuple2Index(GraphStart_tuple) #should be same as data.GraphStart, but is not due rounding
-    print "Indexes:",  GraphStart_index,  "(",  data.GraphStart, ")",  LastFullHour_index
+#    print "Indexes:",  GraphStart_index,  "(",  data.GraphStart, ")",  LastFullHour_index
     
     OffsetToLastFullHour=-1*(GraphStart_index-LastFullHour_index)/Xscale 
     OffsetToLastFullHour=OffsetToLastFullHour-data.Derivation/Xscale  #Derivation takes 5 idnices, so visualisation is delayed!
 
-    print "Last data is on:",  Index2Tuple(records.Index)
+#    print "Last data is on:",  Index2Tuple(records.Index)
     
     #DRAW main scaling lines + text        
     paint.setPen(QtGui.QColor("white"))
@@ -406,7 +408,7 @@ def showGraph(self,  QtGui):
 #            if(x11>1 and x11<779):        
         paint.drawRect(x10,  4,  1,  10)  #Last Alarm opportunity
                 
-        if(data.AlarmIsActive==True or data.run==0): #only show alarm if alarm occured or in record
+        if(data.AlarmIsActive==True or data.run==False): #only show alarm if alarm occured or in record
 #            if(records.Index>=Tuple2Index(records.AlarmTimeWindowEnd_tuple)): #only show alarm dot when alarm really came
             if(records.AlarmTime_seconds!=-1):
                 paint.setBrush(QtGui.QColor("Red"))
@@ -455,22 +457,20 @@ def showGraph(self,  QtGui):
     #beep in test mode
     if(peak>data.Trigger): #if last value is over peak
         if(data.QuickMode==True and (records.Index-data.Derivation)>data.last_beep): #quick mode for testing but only once per move
-            print "Beep"
+            if(data.debug==1): print "Beep"
             data.last_beep=records.Index
             if(data.demo==False): #make beep for testing movement                    
                 b = os.popen("pacat --channels=2 /usr/share/sounds/ui-default_beep.wav")
                 b.close()
 
-# ######## END of showGraph ################################################
 
 
 
 
 
-
-
-
-    
+###########################################################################
+## 
+###########################################################################  
 def ScrollbarData():        
     Xscale=data.arrXscale[data.Xscale]
     data.GraphLen=(records.LastIndex+5)/Xscale
@@ -494,9 +494,10 @@ def ScrollbarData():
 
 
 
-
+###########################################################################
+## 
+###########################################################################
 def InitRecord():
-    print "Reset/clear all record data"
     records.Index=0    
     records.LastIndex=0
     records.StartTime_tuple=time.localtime()
@@ -522,6 +523,7 @@ def InitRecord():
             records.arrData[j][i]=0
         records.arrData[5][i]=""
     
+    print "Reset/cleared all record data"
     
     
     
@@ -530,8 +532,10 @@ def InitRecord():
 
 
 
-
-# # Only used for debugging
+###########################################################################
+## 
+## Only used for debugging
+###########################################################################
 def PrintRecordData(ShowArray=True):
     print "###################### RECORD DATA #######################"
     print "Index:",  records.Index    
